# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/datasource/v1/logsource.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/datasource/v1/logsource.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0insightproto/proto/datasource/v1/logsource.proto\x12 insightproto.proto.datasource.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\"\xd0\x01\n\x08LogEntry\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05level\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x46\n\x06labels\x18\x04 \x03(\x0b\x32\x36.insightproto.proto.datasource.v1.LogEntry.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb1\x01\n\x08Metadata\x12\x11\n\tlog_count\x18\x01 \x01(\x05\x12\x34\n\x06source\x18\x02 \x01(\x0b\x32$.insightproto.proto.common.v1.Source\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x88\x01\n\x0bLogResponse\x12;\n\x07\x65ntries\x18\x01 \x03(\x0b\x32*.insightproto.proto.datasource.v1.LogEntry\x12<\n\x08metadata\x18\x02 \x01(\x0b\x32*.insightproto.proto.datasource.v1.Metadata\"\xab\x02\n\nLogRequest\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05query\x18\x03 \x01(\t\x12H\n\x06labels\x18\x04 \x03(\x0b\x32\x38.insightproto.proto.datasource.v1.LogRequest.LabelsEntry\x12\x37\n\x03org\x18\x05 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\x10MultipleResponse\x12\x37\n\x03org\x18\x01 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12@\n\tresponses\x18\x02 \x03(\x0b\x32-.insightproto.proto.datasource.v1.LogResponse2\xec\x01\n\x0eLoggingService\x12m\n\tQueryLogs\x12,.insightproto.proto.datasource.v1.LogRequest\x1a\x32.insightproto.proto.datasource.v1.MultipleResponse\x12k\n\nStreamLogs\x12,.insightproto.proto.datasource.v1.LogRequest\x1a-.insightproto.proto.datasource.v1.LogResponse0\x01\x42\x35Z3github.com/opentrace/insight-proto-go/datasource/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.datasource.v1.logsource_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/opentrace/insight-proto-go/datasource/v1'
  _globals['_LOGENTRY_LABELSENTRY']._loaded_options = None
  _globals['_LOGENTRY_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LOGREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_LOGREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LOGENTRY']._serialized_start=163
  _globals['_LOGENTRY']._serialized_end=371
  _globals['_LOGENTRY_LABELSENTRY']._serialized_start=326
  _globals['_LOGENTRY_LABELSENTRY']._serialized_end=371
  _globals['_METADATA']._serialized_start=374
  _globals['_METADATA']._serialized_end=551
  _globals['_LOGRESPONSE']._serialized_start=554
  _globals['_LOGRESPONSE']._serialized_end=690
  _globals['_LOGREQUEST']._serialized_start=693
  _globals['_LOGREQUEST']._serialized_end=992
  _globals['_LOGREQUEST_LABELSENTRY']._serialized_start=326
  _globals['_LOGREQUEST_LABELSENTRY']._serialized_end=371
  _globals['_MULTIPLERESPONSE']._serialized_start=995
  _globals['_MULTIPLERESPONSE']._serialized_end=1136
  _globals['_LOGGINGSERVICE']._serialized_start=1139
  _globals['_LOGGINGSERVICE']._serialized_end=1375
# @@protoc_insertion_point(module_scope)
