# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/jobs/v1/jobs.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/jobs/v1/jobs.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2
from insightproto.proto.jobs.v1 import job_service_pb2 as insightproto_dot_proto_dot_jobs_dot_v1_dot_job__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%insightproto/proto/jobs/v1/jobs.proto\x12\x1ainsightproto.proto.jobs.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\x1a,insightproto/proto/jobs/v1/job_service.proto\"\xd8\x03\n\nJobMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12\x43\n\x0fidempotency_key\x18\x07 \x01(\tB*\x9a\x84\x9e\x03%firestore:\"idempotency_key,omitempty\"\x12;\n\naether_job\x18\x03 \x01(\x0b\x32%.insightproto.proto.jobs.v1.AetherJobH\x00\x12=\n\x0binsight_job\x18\x04 \x01(\x0b\x32&.insightproto.proto.jobs.v1.InsightJobH\x00\x12\x41\n\rsimulator_job\x18\x05 \x01(\x0b\x32(.insightproto.proto.jobs.v1.SimulatorJobH\x00\x12\x41\n\rknowledge_job\x18\x06 \x01(\x0b\x32(.insightproto.proto.jobs.v1.KnowledgeJobH\x00\x12\x37\n\x08\x63hat_job\x18\x08 \x01(\x0b\x32#.insightproto.proto.jobs.v1.ChatJobH\x00\x42\x05\n\x03job\"\xd0\x02\n\x0cSimulatorJob\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x61gent\x18\x02 \x01(\t\x12\x12\n\x06inputs\x18\x03 \x03(\tB\x02\x18\x01\x12t\n\rinsight_agent\x18\x04 \x01(\x0b\x32..insightproto.proto.jobs.v1.InsightAgentConfigB(\x9a\x84\x9e\x03#firestore:\"insight_agent,omitempty\"H\x00\x88\x01\x01\x12\x17\n\ntest_suite\x18\x05 \x01(\tH\x01\x88\x01\x01\x12W\n\x05\x65rror\x18\x06 \x01(\x0b\x32!.insightproto.proto.jobs.v1.ErrorB \x9a\x84\x9e\x03\x1b\x66irestore:\"error,omitempty\"H\x02\x88\x01\x01\x42\x10\n\x0e_insight_agentB\r\n\x0b_test_suiteB\x08\n\x06_error\"\x8f\x02\n\x12InsightAgentConfig\x12p\n\x0binvestigate\x18\x01 \x01(\x0b\x32..insightproto.proto.jobs.v1.InvestigateCommandB&\x9a\x84\x9e\x03!firestore:\"investigate,omitempty\"H\x00\x88\x01\x01\x12i\n\trun_agent\x18\x02 \x01(\x0b\x32+.insightproto.proto.jobs.v1.RunAgentCommandB$\x9a\x84\x9e\x03\x1f\x66irestore:\"run_agent,omitempty\"H\x01\x88\x01\x01\x42\x0e\n\x0c_investigateB\x0c\n\n_run_agent\"#\n\x12InvestigateCommand\x12\r\n\x05query\x18\x01 \x01(\t\"\\\n\x0fRunAgentCommand\x12\x13\n\x0b\x61gent_class\x18\x01 \x01(\t\x12\x13\n\x0bserver_name\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\"\xc6\x02\n\x07\x43hatJob\x12\x17\n\x0f\x63onversation_id\x18\x01 \x01(\t\x12\x13\n\x0bresponse_id\x18\x02 \x01(\t\x12\\\n\x07history\x18\x03 \x03(\x0b\x32\'.insightproto.proto.jobs.v1.ChatMessageB\"\x9a\x84\x9e\x03\x1d\x66irestore:\"history,omitempty\"\x12@\n\x0f\x63urrent_message\x18\x04 \x01(\x0b\x32\'.insightproto.proto.jobs.v1.ChatMessage\x12\x61\n\x07\x63ontext\x18\x05 \x01(\x0b\x32\'.insightproto.proto.jobs.v1.ChatContextB\"\x9a\x84\x9e\x03\x1d\x66irestore:\"context,omitempty\"H\x00\x88\x01\x01\x42\n\n\x08_context\"[\n\x0b\x43hatMessage\x12\x0c\n\x04role\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa5\x01\n\x0b\x43hatContext\x12J\n\x10investigation_id\x18\x01 \x01(\tB+\x9a\x84\x9e\x03&firestore:\"investigation_id,omitempty\"H\x00\x88\x01\x01\x12\x35\n\x08node_ids\x18\x02 \x03(\tB#\x9a\x84\x9e\x03\x1e\x66irestore:\"node_ids,omitempty\"B\x13\n\x11_investigation_id\"\xf9\x04\n\x0cKnowledgeJob\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x06source\x18\x02 \x01(\x0b\x32$.insightproto.proto.common.v1.Source\x12\x65\n\x07project\x18\x03 \x01(\x0b\x32+.insightproto.proto.jobs.v1.ProviderProjectB\"\x9a\x84\x9e\x03\x1d\x66irestore:\"project,omitempty\"H\x00\x88\x01\x01\x12Z\n\x06\x61uthor\x18\x04 \x01(\x0b\x32\".insightproto.proto.jobs.v1.AuthorB!\x9a\x84\x9e\x03\x1c\x66irestore:\"author,omitempty\"H\x01\x88\x01\x01\x12l\n\nkubernetes\x18\x05 \x01(\x0b\x32,.insightproto.proto.jobs.v1.KubernetesConfigB%\x9a\x84\x9e\x03 firestore:\"kubernetes,omitempty\"H\x02\x88\x01\x01\x12]\n\x05issue\x18\x06 \x01(\x0b\x32\'.insightproto.proto.jobs.v1.IssueConfigB \x9a\x84\x9e\x03\x1b\x66irestore:\"issue,omitempty\"H\x03\x88\x01\x01\x12]\n\x05trace\x18\x07 \x01(\x0b\x32\'.insightproto.proto.jobs.v1.TraceConfigB \x9a\x84\x9e\x03\x1b\x66irestore:\"trace,omitempty\"H\x04\x88\x01\x01\x42\n\n\x08_projectB\t\n\x07_authorB\r\n\x0b_kubernetesB\x08\n\x06_issueB\x08\n\x06_trace\"P\n\x0bTraceConfig\x12\x41\n\x0eservice_filter\x18\x01 \x03(\tB)\x9a\x84\x9e\x03$firestore:\"service_filter,omitempty\"\"\xb6\x02\n\x10KubernetesConfig\x12\x45\n\x10namespace_filter\x18\x01 \x03(\tB+\x9a\x84\x9e\x03&firestore:\"namespace_filter,omitempty\"\x12W\n\x19include_system_namespaces\x18\x02 \x01(\x08\x42\x34\x9a\x84\x9e\x03/firestore:\"include_system_namespaces,omitempty\"\x12=\n\x0c\x63luster_name\x18\x03 \x01(\tB\'\x9a\x84\x9e\x03\"firestore:\"cluster_name,omitempty\"\x12\x43\n\x0f\x63luster_context\x18\x04 \x01(\tB*\x9a\x84\x9e\x03%firestore:\"cluster_context,omitempty\"\"%\n\x0bIssueConfig\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x05\n\x03_id\"\xde\x02\n\tAetherJob\x12\n\n\x02id\x18\x01 \x01(\t\x12<\n\x07project\x18\x02 \x01(\x0b\x32+.insightproto.proto.jobs.v1.ProviderProject\x12\x15\n\rOperationType\x18\x03 \x01(\t\x12\x14\n\x07IssueId\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0c\x44iscussionId\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0eMergeRequestId\x18\x06 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05JobId\x18\x07 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06NoteId\x18\x08 \x01(\tH\x04\x88\x01\x01\x12\x34\n\x06source\x18\t \x01(\x0b\x32$.insightproto.proto.common.v1.SourceB\n\n\x08_IssueIdB\x0f\n\r_DiscussionIdB\x11\n\x0f_MergeRequestIdB\x08\n\x06_JobIdB\t\n\x07_NoteId\"\x95\x01\n\x0fProviderProject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12:\n\x08provider\x18\x03 \x01(\x0b\x32$.insightproto.proto.jobs.v1.ProviderB\x02\x18\x01\x12\x1b\n\x13\x64\x65\x66\x61ult_branch_name\x18\x04 \x01(\t\x12\x0f\n\x07git_url\x18\x05 \x01(\t\"B\n\x08Provider\x12\x0e\n\x02id\x18\x01 \x01(\tB\x02\x18\x01\x12\x12\n\x06source\x18\x02 \x01(\tB\x02\x18\x01\x12\x12\n\x06gitUrl\x18\x03 \x01(\tB\x02\x18\x01\"N\n\nInsightJob\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x07trigger\x18\x02 \x01(\x0b\x32#.insightproto.proto.jobs.v1.Trigger\"\xd4\x02\n\x07Trigger\x12\x34\n\x06source\x18\x01 \x01(\x0b\x32$.insightproto.proto.common.v1.Source\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x42\n\x0creference_id\x18\x03 \x01(\tB\'\x9a\x84\x9e\x03\"firestore:\"reference_id,omitempty\"H\x00\x88\x01\x01\x12\x32\n\x06\x61uthor\x18\x04 \x01(\x0b\x32\".insightproto.proto.jobs.v1.Author\x12-\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\nchannel_id\x18\x06 \x01(\tB%\x9a\x84\x9e\x03 firestore:\"channel_id,omitempty\"H\x01\x88\x01\x01\x42\x0f\n\r_reference_idB\r\n\x0b_channel_id\"2\n\x06\x41uthor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x03 \x01(\tB/Z-github.com/opentrace/insight-proto-go/jobs/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.jobs.v1.jobs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/opentrace/insight-proto-go/jobs/v1'
  _globals['_JOBMESSAGE'].fields_by_name['idempotency_key']._loaded_options = None
  _globals['_JOBMESSAGE'].fields_by_name['idempotency_key']._serialized_options = b'\232\204\236\003%firestore:\"idempotency_key,omitempty\"'
  _globals['_SIMULATORJOB'].fields_by_name['inputs']._loaded_options = None
  _globals['_SIMULATORJOB'].fields_by_name['inputs']._serialized_options = b'\030\001'
  _globals['_SIMULATORJOB'].fields_by_name['insight_agent']._loaded_options = None
  _globals['_SIMULATORJOB'].fields_by_name['insight_agent']._serialized_options = b'\232\204\236\003#firestore:\"insight_agent,omitempty\"'
  _globals['_SIMULATORJOB'].fields_by_name['error']._loaded_options = None
  _globals['_SIMULATORJOB'].fields_by_name['error']._serialized_options = b'\232\204\236\003\033firestore:\"error,omitempty\"'
  _globals['_INSIGHTAGENTCONFIG'].fields_by_name['investigate']._loaded_options = None
  _globals['_INSIGHTAGENTCONFIG'].fields_by_name['investigate']._serialized_options = b'\232\204\236\003!firestore:\"investigate,omitempty\"'
  _globals['_INSIGHTAGENTCONFIG'].fields_by_name['run_agent']._loaded_options = None
  _globals['_INSIGHTAGENTCONFIG'].fields_by_name['run_agent']._serialized_options = b'\232\204\236\003\037firestore:\"run_agent,omitempty\"'
  _globals['_CHATJOB'].fields_by_name['history']._loaded_options = None
  _globals['_CHATJOB'].fields_by_name['history']._serialized_options = b'\232\204\236\003\035firestore:\"history,omitempty\"'
  _globals['_CHATJOB'].fields_by_name['context']._loaded_options = None
  _globals['_CHATJOB'].fields_by_name['context']._serialized_options = b'\232\204\236\003\035firestore:\"context,omitempty\"'
  _globals['_CHATCONTEXT'].fields_by_name['investigation_id']._loaded_options = None
  _globals['_CHATCONTEXT'].fields_by_name['investigation_id']._serialized_options = b'\232\204\236\003&firestore:\"investigation_id,omitempty\"'
  _globals['_CHATCONTEXT'].fields_by_name['node_ids']._loaded_options = None
  _globals['_CHATCONTEXT'].fields_by_name['node_ids']._serialized_options = b'\232\204\236\003\036firestore:\"node_ids,omitempty\"'
  _globals['_KNOWLEDGEJOB'].fields_by_name['project']._loaded_options = None
  _globals['_KNOWLEDGEJOB'].fields_by_name['project']._serialized_options = b'\232\204\236\003\035firestore:\"project,omitempty\"'
  _globals['_KNOWLEDGEJOB'].fields_by_name['author']._loaded_options = None
  _globals['_KNOWLEDGEJOB'].fields_by_name['author']._serialized_options = b'\232\204\236\003\034firestore:\"author,omitempty\"'
  _globals['_KNOWLEDGEJOB'].fields_by_name['kubernetes']._loaded_options = None
  _globals['_KNOWLEDGEJOB'].fields_by_name['kubernetes']._serialized_options = b'\232\204\236\003 firestore:\"kubernetes,omitempty\"'
  _globals['_KNOWLEDGEJOB'].fields_by_name['issue']._loaded_options = None
  _globals['_KNOWLEDGEJOB'].fields_by_name['issue']._serialized_options = b'\232\204\236\003\033firestore:\"issue,omitempty\"'
  _globals['_KNOWLEDGEJOB'].fields_by_name['trace']._loaded_options = None
  _globals['_KNOWLEDGEJOB'].fields_by_name['trace']._serialized_options = b'\232\204\236\003\033firestore:\"trace,omitempty\"'
  _globals['_TRACECONFIG'].fields_by_name['service_filter']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['service_filter']._serialized_options = b'\232\204\236\003$firestore:\"service_filter,omitempty\"'
  _globals['_KUBERNETESCONFIG'].fields_by_name['namespace_filter']._loaded_options = None
  _globals['_KUBERNETESCONFIG'].fields_by_name['namespace_filter']._serialized_options = b'\232\204\236\003&firestore:\"namespace_filter,omitempty\"'
  _globals['_KUBERNETESCONFIG'].fields_by_name['include_system_namespaces']._loaded_options = None
  _globals['_KUBERNETESCONFIG'].fields_by_name['include_system_namespaces']._serialized_options = b'\232\204\236\003/firestore:\"include_system_namespaces,omitempty\"'
  _globals['_KUBERNETESCONFIG'].fields_by_name['cluster_name']._loaded_options = None
  _globals['_KUBERNETESCONFIG'].fields_by_name['cluster_name']._serialized_options = b'\232\204\236\003\"firestore:\"cluster_name,omitempty\"'
  _globals['_KUBERNETESCONFIG'].fields_by_name['cluster_context']._loaded_options = None
  _globals['_KUBERNETESCONFIG'].fields_by_name['cluster_context']._serialized_options = b'\232\204\236\003%firestore:\"cluster_context,omitempty\"'
  _globals['_PROVIDERPROJECT'].fields_by_name['provider']._loaded_options = None
  _globals['_PROVIDERPROJECT'].fields_by_name['provider']._serialized_options = b'\030\001'
  _globals['_PROVIDER'].fields_by_name['id']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['id']._serialized_options = b'\030\001'
  _globals['_PROVIDER'].fields_by_name['source']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['source']._serialized_options = b'\030\001'
  _globals['_PROVIDER'].fields_by_name['gitUrl']._loaded_options = None
  _globals['_PROVIDER'].fields_by_name['gitUrl']._serialized_options = b'\030\001'
  _globals['_TRIGGER'].fields_by_name['reference_id']._loaded_options = None
  _globals['_TRIGGER'].fields_by_name['reference_id']._serialized_options = b'\232\204\236\003\"firestore:\"reference_id,omitempty\"'
  _globals['_TRIGGER'].fields_by_name['channel_id']._loaded_options = None
  _globals['_TRIGGER'].fields_by_name['channel_id']._serialized_options = b'\232\204\236\003 firestore:\"channel_id,omitempty\"'
  _globals['_JOBMESSAGE']._serialized_start=192
  _globals['_JOBMESSAGE']._serialized_end=664
  _globals['_SIMULATORJOB']._serialized_start=667
  _globals['_SIMULATORJOB']._serialized_end=1003
  _globals['_INSIGHTAGENTCONFIG']._serialized_start=1006
  _globals['_INSIGHTAGENTCONFIG']._serialized_end=1277
  _globals['_INVESTIGATECOMMAND']._serialized_start=1279
  _globals['_INVESTIGATECOMMAND']._serialized_end=1314
  _globals['_RUNAGENTCOMMAND']._serialized_start=1316
  _globals['_RUNAGENTCOMMAND']._serialized_end=1408
  _globals['_CHATJOB']._serialized_start=1411
  _globals['_CHATJOB']._serialized_end=1737
  _globals['_CHATMESSAGE']._serialized_start=1739
  _globals['_CHATMESSAGE']._serialized_end=1830
  _globals['_CHATCONTEXT']._serialized_start=1833
  _globals['_CHATCONTEXT']._serialized_end=1998
  _globals['_KNOWLEDGEJOB']._serialized_start=2001
  _globals['_KNOWLEDGEJOB']._serialized_end=2634
  _globals['_TRACECONFIG']._serialized_start=2636
  _globals['_TRACECONFIG']._serialized_end=2716
  _globals['_KUBERNETESCONFIG']._serialized_start=2719
  _globals['_KUBERNETESCONFIG']._serialized_end=3029
  _globals['_ISSUECONFIG']._serialized_start=3031
  _globals['_ISSUECONFIG']._serialized_end=3068
  _globals['_AETHERJOB']._serialized_start=3071
  _globals['_AETHERJOB']._serialized_end=3421
  _globals['_PROVIDERPROJECT']._serialized_start=3424
  _globals['_PROVIDERPROJECT']._serialized_end=3573
  _globals['_PROVIDER']._serialized_start=3575
  _globals['_PROVIDER']._serialized_end=3641
  _globals['_INSIGHTJOB']._serialized_start=3643
  _globals['_INSIGHTJOB']._serialized_end=3721
  _globals['_TRIGGER']._serialized_start=3724
  _globals['_TRIGGER']._serialized_end=4064
  _globals['_AUTHOR']._serialized_start=4066
  _globals['_AUTHOR']._serialized_end=4116
# @@protoc_insertion_point(module_scope)
