# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/flow.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/flow.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(insightproto/proto/results/v1/flow.proto\x12\x1dinsightproto.proto.results.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\"\xe2\x02\n\nAgentEvent\x12\x18\n\x10investigation_id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61gentId\x18\x04 \x01(\t\x12\x38\n\x07thought\x18\x05 \x01(\tB\"\x9a\x84\x9e\x03\x1d\x66irestore:\"thought,omitempty\"H\x00\x88\x01\x01\x12\x32\n\x04tool\x18\x06 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"tool,omitempty\"H\x01\x88\x01\x01\x12\x34\n\x05\x65rror\x18\x07 \x01(\tB \x9a\x84\x9e\x03\x1b\x66irestore:\"error,omitempty\"H\x02\x88\x01\x01\x42\n\n\x08_thoughtB\x07\n\x05_toolB\x08\n\x06_error\"\xd9\x01\n\x11\x41gentStartedEvent\x12\x18\n\x10investigation_id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rparentAgentId\x18\x04 \x01(\t\x12\x0f\n\x07\x61gentId\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0c\n\x04goal\x18\x07 \x01(\t\"\xe6\x01\n\x11\x41gentStoppedEvent\x12\x18\n\x10investigation_id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x61gentId\x18\x04 \x01(\t\x12\x34\n\x05\x65rror\x18\x05 \x01(\tB \x9a\x84\x9e\x03\x1b\x66irestore:\"error,omitempty\"H\x00\x88\x01\x01\x42\x08\n\x06_error2\x94\x02\n\tAgentFlow\x12X\n\x0c\x41gentStarted\x12\x30.insightproto.proto.results.v1.AgentStartedEvent\x1a\x16.google.protobuf.Empty\x12S\n\x0eSendAgentEvent\x12).insightproto.proto.results.v1.AgentEvent\x1a\x16.google.protobuf.Empty\x12X\n\x0c\x41gentStopped\x12\x30.insightproto.proto.results.v1.AgentStoppedEvent\x1a\x16.google.protobuf.EmptyB2Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.flow_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_AGENTEVENT'].fields_by_name['thought']._loaded_options = None
  _globals['_AGENTEVENT'].fields_by_name['thought']._serialized_options = b'\232\204\236\003\035firestore:\"thought,omitempty\"'
  _globals['_AGENTEVENT'].fields_by_name['tool']._loaded_options = None
  _globals['_AGENTEVENT'].fields_by_name['tool']._serialized_options = b'\232\204\236\003\032firestore:\"tool,omitempty\"'
  _globals['_AGENTEVENT'].fields_by_name['error']._loaded_options = None
  _globals['_AGENTEVENT'].fields_by_name['error']._serialized_options = b'\232\204\236\003\033firestore:\"error,omitempty\"'
  _globals['_AGENTSTOPPEDEVENT'].fields_by_name['error']._loaded_options = None
  _globals['_AGENTSTOPPEDEVENT'].fields_by_name['error']._serialized_options = b'\232\204\236\003\033firestore:\"error,omitempty\"'
  _globals['_AGENTEVENT']._serialized_start=181
  _globals['_AGENTEVENT']._serialized_end=535
  _globals['_AGENTSTARTEDEVENT']._serialized_start=538
  _globals['_AGENTSTARTEDEVENT']._serialized_end=755
  _globals['_AGENTSTOPPEDEVENT']._serialized_start=758
  _globals['_AGENTSTOPPEDEVENT']._serialized_end=988
  _globals['_AGENTFLOW']._serialized_start=991
  _globals['_AGENTFLOW']._serialized_end=1267
# @@protoc_insertion_point(module_scope)
