# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/jobs/v1/job_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/jobs/v1/job_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,insightproto/proto/jobs/v1/job_service.proto\x12\x1ainsightproto.proto.jobs.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a)insightproto/proto/common/v1/common.proto\"T\n\rJobStartEvent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\"\x94\x01\n\x0cJobStopEvent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12\x35\n\x05\x65rror\x18\x03 \x01(\x0b\x32!.insightproto.proto.jobs.v1.ErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"8\n\x05\x45rror\x12\x0f\n\x07\x65rrType\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05trace\x18\x03 \x01(\t2\xa8\x01\n\nJobService\x12M\n\x08JobStart\x12).insightproto.proto.jobs.v1.JobStartEvent\x1a\x16.google.protobuf.Empty\x12K\n\x07JobStop\x12(.insightproto.proto.jobs.v1.JobStopEvent\x1a\x16.google.protobuf.EmptyB/Z-github.com/opentrace/insight-proto-go/jobs/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.jobs.v1.job_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/opentrace/insight-proto-go/jobs/v1'
  _globals['_JOBSTARTEVENT']._serialized_start=148
  _globals['_JOBSTARTEVENT']._serialized_end=232
  _globals['_JOBSTOPEVENT']._serialized_start=235
  _globals['_JOBSTOPEVENT']._serialized_end=383
  _globals['_ERROR']._serialized_start=385
  _globals['_ERROR']._serialized_end=441
  _globals['_JOBSERVICE']._serialized_start=444
  _globals['_JOBSERVICE']._serialized_end=612
# @@protoc_insertion_point(module_scope)
