# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/jobs/v2/job_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/jobs/v2/job_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,insightproto/proto/jobs/v2/job_service.proto\x12\x1ainsightproto.proto.jobs.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a)insightproto/proto/common/v1/common.proto\"R\n\rJobIdentifier\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.insightproto.proto.jobs.v2.JobType\"\xbb\x05\n\x08JobEvent\x12\x37\n\x03org\x18\x01 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12\x36\n\x03job\x18\x02 \x01(\x0b\x32).insightproto.proto.jobs.v2.JobIdentifier\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x05\x61gent\x18\x04 \x01(\x0b\x32!.insightproto.proto.jobs.v2.Agent\x12;\n\x07thought\x18\n \x01(\x0b\x32(.insightproto.proto.jobs.v2.ThoughtEventH\x00\x12>\n\ttool_call\x18\x0b \x01(\x0b\x32).insightproto.proto.jobs.v2.ToolCallEventH\x00\x12\x42\n\x0btool_result\x18\x0c \x01(\x0b\x32+.insightproto.proto.jobs.v2.ToolResultEventH\x00\x12\x46\n\ragent_started\x18\r \x01(\x0b\x32-.insightproto.proto.jobs.v2.AgentStartedEventH\x00\x12\x46\n\ragent_stopped\x18\x0e \x01(\x0b\x32-.insightproto.proto.jobs.v2.AgentStoppedEventH\x00\x12=\n\x08progress\x18\x0f \x01(\x0b\x32).insightproto.proto.jobs.v2.ProgressEventH\x00\x12\x44\n\x0c\x63hat_content\x18\x10 \x01(\x0b\x32,.insightproto.proto.jobs.v2.ChatContentEventH\x00\x42\x07\n\x05\x65vent\"\x15\n\x05\x41gent\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1f\n\x0cThoughtEvent\x12\x0f\n\x07thought\x18\x01 \x01(\t\"\x8c\x01\n\rToolCallEvent\x12\x14\n\x0ctool_call_id\x18\x01 \x01(\t\x12\x11\n\ttool_name\x18\x02 \x01(\t\x12\x17\n\nmcp_server\x18\x03 \x01(\tH\x00\x88\x01\x01\x12*\n\targuments\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructB\r\n\x0b_mcp_server\"\xb4\x01\n\x0fToolResultEvent\x12\x14\n\x0ctool_call_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12,\n\x06result\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x0b\x64uration_ms\x18\x05 \x01(\x03\x42\t\n\x07_resultB\x10\n\x0e_error_message\"/\n\x11\x41gentStartedEvent\x12\x11\n\x04goal\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_goal\"1\n\x11\x41gentStoppedEvent\x12\x12\n\x05\x65rror\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_error\"B\n\rProgressEvent\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x14\n\x07percent\x18\x02 \x01(\x05H\x00\x88\x01\x01\x42\n\n\x08_percent\"\x84\x01\n\x10\x43hatContentEvent\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\x08sequence\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x08\x63omplete\x18\x03 \x01(\x08\x12\x17\n\x0f\x63onversation_id\x18\x04 \x01(\t\x12\x13\n\x0bresponse_id\x18\x05 \x01(\tB\x0b\n\t_sequence*\x91\x01\n\x07JobType\x12\x18\n\x14JOB_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10JOB_TYPE_INSIGHT\x10\x01\x12\x13\n\x0fJOB_TYPE_AETHER\x10\x02\x12\x16\n\x12JOB_TYPE_SIMULATOR\x10\x03\x12\x16\n\x12JOB_TYPE_KNOWLEDGE\x10\x04\x12\x11\n\rJOB_TYPE_CHAT\x10\x05\x32W\n\nJobService\x12I\n\tPostEvent\x12$.insightproto.proto.jobs.v2.JobEvent\x1a\x16.google.protobuf.EmptyB/Z-github.com/opentrace/insight-proto-go/jobs/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.jobs.v2.job_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/opentrace/insight-proto-go/jobs/v2'
  _globals['_JOBTYPE']._serialized_start=1683
  _globals['_JOBTYPE']._serialized_end=1828
  _globals['_JOBIDENTIFIER']._serialized_start=211
  _globals['_JOBIDENTIFIER']._serialized_end=293
  _globals['_JOBEVENT']._serialized_start=296
  _globals['_JOBEVENT']._serialized_end=995
  _globals['_AGENT']._serialized_start=997
  _globals['_AGENT']._serialized_end=1018
  _globals['_THOUGHTEVENT']._serialized_start=1020
  _globals['_THOUGHTEVENT']._serialized_end=1051
  _globals['_TOOLCALLEVENT']._serialized_start=1054
  _globals['_TOOLCALLEVENT']._serialized_end=1194
  _globals['_TOOLRESULTEVENT']._serialized_start=1197
  _globals['_TOOLRESULTEVENT']._serialized_end=1377
  _globals['_AGENTSTARTEDEVENT']._serialized_start=1379
  _globals['_AGENTSTARTEDEVENT']._serialized_end=1426
  _globals['_AGENTSTOPPEDEVENT']._serialized_start=1428
  _globals['_AGENTSTOPPEDEVENT']._serialized_end=1477
  _globals['_PROGRESSEVENT']._serialized_start=1479
  _globals['_PROGRESSEVENT']._serialized_end=1545
  _globals['_CHATCONTENTEVENT']._serialized_start=1548
  _globals['_CHATCONTENTEVENT']._serialized_end=1680
  _globals['_JOBSERVICE']._serialized_start=1830
  _globals['_JOBSERVICE']._serialized_end=1917
# @@protoc_insertion_point(module_scope)
