# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/simulator.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/simulator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2
from insightproto.proto.jobs.v1 import jobs_pb2 as insightproto_dot_proto_dot_jobs_dot_v1_dot_jobs__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-insightproto/proto/results/v1/simulator.proto\x12\x1dinsightproto.proto.results.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\x1a%insightproto/proto/jobs/v1/jobs.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xd8\x02\n\x17SimulatorResultsRequest\x12\x37\n\x03org\x18\x01 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12?\n\rsimulator_job\x18\x02 \x01(\x0b\x32(.insightproto.proto.jobs.v1.SimulatorJob\x12\x15\n\ragent_job_ids\x18\x03 \x03(\t\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12J\n\x11\x65valuation_result\x18\x06 \x01(\x0b\x32/.insightproto.proto.results.v1.EvaluationResult\"\xab\x02\n\x10\x45valuationResult\x12\x0f\n\x07summary\x18\x01 \x01(\t\x12\x15\n\roverall_score\x18\x02 \x01(\x05\x12\x18\n\x10\x61nalysis_quality\x18\x03 \x01(\t\x12\x1b\n\x13\x61\x63\x63uracy_assessment\x18\x04 \x01(\t\x12R\n\x15\x61reas_for_improvement\x18\x05 \x01(\tB.\x9a\x84\x9e\x03)firestore:\"areasForImprovement,omitempty\"H\x00\x88\x01\x01\x12<\n\tstrengths\x18\x06 \x01(\tB$\x9a\x84\x9e\x03\x1f\x66irestore:\"strengths,omitempty\"H\x01\x88\x01\x01\x42\x18\n\x16_areas_for_improvementB\x0c\n\n_strengths2z\n\x17SimulatorResultsService\x12_\n\rSubmitResults\x12\x36.insightproto.proto.results.v1.SimulatorResultsRequest\x1a\x16.google.protobuf.EmptyB2Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.simulator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_EVALUATIONRESULT'].fields_by_name['areas_for_improvement']._loaded_options = None
  _globals['_EVALUATIONRESULT'].fields_by_name['areas_for_improvement']._serialized_options = b'\232\204\236\003)firestore:\"areasForImprovement,omitempty\"'
  _globals['_EVALUATIONRESULT'].fields_by_name['strengths']._loaded_options = None
  _globals['_EVALUATIONRESULT'].fields_by_name['strengths']._serialized_options = b'\232\204\236\003\037firestore:\"strengths,omitempty\"'
  _globals['_SIMULATORRESULTSREQUEST']._serialized_start=225
  _globals['_SIMULATORRESULTSREQUEST']._serialized_end=569
  _globals['_EVALUATIONRESULT']._serialized_start=572
  _globals['_EVALUATIONRESULT']._serialized_end=871
  _globals['_SIMULATORRESULTSSERVICE']._serialized_start=873
  _globals['_SIMULATORRESULTSSERVICE']._serialized_end=995
# @@protoc_insertion_point(module_scope)
