# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/results/v1/knowledge.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/results/v1/knowledge.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2
from insightproto.proto.results.v1 import timeline_details_pb2 as insightproto_dot_proto_dot_results_dot_v1_dot_timeline__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-insightproto/proto/results/v1/knowledge.proto\x12\x1dinsightproto.proto.results.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\x1a\x34insightproto/proto/results/v1/timeline_details.proto\"\x97\x01\n\x0b\x41\x63quisition\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12\x43\n\tknowledge\x18\x03 \x01(\x0b\x32\x30.insightproto.proto.results.v1.KnowledgeActivity\"\x8b\x04\n\x11KnowledgeActivity\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x06source\x18\x02 \x01(\x0b\x32$.insightproto.proto.common.v1.Source\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12[\n\x06\x61uthor\x18\x05 \x01(\x0b\x32#.insightproto.proto.results.v1.UserB!\x9a\x84\x9e\x03\x1c\x66irestore:\"author,omitempty\"H\x00\x88\x01\x01\x12-\n\tcreatedAt\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x04link\x18\x07 \x01(\tB\x1f\x9a\x84\x9e\x03\x1a\x66irestore:\"link,omitempty\"H\x01\x88\x01\x01\x12g\n\x08metadata\x18\x08 \x03(\x0b\x32\x30.insightproto.proto.results.v1.KnowledgeMetadataB#\x9a\x84\x9e\x03\x1e\x66irestore:\"metadata,omitempty\"\x12S\n\texpiresAt\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB$\x9a\x84\x9e\x03\x1f\x66irestore:\"expiresAt,omitempty\"B\t\n\x07_authorB\x07\n\x05_link\"B\n\x11KnowledgeMetadata\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x10\n\x08typeName\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x05\x32k\n\x10KnowledgeService\x12W\n\x11KnowledgeAcquired\x12*.insightproto.proto.results.v1.Acquisition\x1a\x16.google.protobuf.EmptyB2Z0github.com/opentrace/insight-proto-go/results/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.results.v1.knowledge_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/opentrace/insight-proto-go/results/v1'
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['author']._loaded_options = None
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['author']._serialized_options = b'\232\204\236\003\034firestore:\"author,omitempty\"'
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['link']._loaded_options = None
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['link']._serialized_options = b'\232\204\236\003\032firestore:\"link,omitempty\"'
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['metadata']._loaded_options = None
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['metadata']._serialized_options = b'\232\204\236\003\036firestore:\"metadata,omitempty\"'
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['expiresAt']._loaded_options = None
  _globals['_KNOWLEDGEACTIVITY'].fields_by_name['expiresAt']._serialized_options = b'\232\204\236\003\037firestore:\"expiresAt,omitempty\"'
  _globals['_ACQUISITION']._serialized_start=240
  _globals['_ACQUISITION']._serialized_end=391
  _globals['_KNOWLEDGEACTIVITY']._serialized_start=394
  _globals['_KNOWLEDGEACTIVITY']._serialized_end=917
  _globals['_KNOWLEDGEMETADATA']._serialized_start=919
  _globals['_KNOWLEDGEMETADATA']._serialized_end=985
  _globals['_KNOWLEDGESERVICE']._serialized_start=987
  _globals['_KNOWLEDGESERVICE']._serialized_end=1094
# @@protoc_insertion_point(module_scope)
