# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: insightproto/proto/events/v1/insight.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'insightproto/proto/events/v1/insight.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from insightproto.proto.common.v1 import common_pb2 as insightproto_dot_proto_dot_common_dot_v1_dot_common__pb2
from insightproto.proto.jobs.v1 import jobs_pb2 as insightproto_dot_proto_dot_jobs_dot_v1_dot_jobs__pb2
from insightproto.proto.results.v1 import results_pb2 as insightproto_dot_proto_dot_results_dot_v1_dot_results__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*insightproto/proto/events/v1/insight.proto\x12\x1cinsightproto.proto.events.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)insightproto/proto/common/v1/common.proto\x1a%insightproto/proto/jobs/v1/jobs.proto\x1a+insightproto/proto/results/v1/results.proto\"\xc8\x02\n\x0fInsightComplete\x12\n\n\x02id\x18\x01 \x01(\t\x12\x37\n\x03org\x18\x02 \x01(\x0b\x32*.insightproto.proto.common.v1.Organisation\x12\x34\n\x07trigger\x18\x03 \x01(\x0b\x32#.insightproto.proto.jobs.v1.Trigger\x12,\n\x08\x63losedAt\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tcreatedAt\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0f\n\x07summary\x18\x07 \x01(\t\x12=\n\nhypotheses\x18\x08 \x01(\x0b\x32).insightproto.proto.results.v1.HypothesisB1Z/github.com/opentrace/insight-proto-go/events/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'insightproto.proto.events.v1.insight_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/opentrace/insight-proto-go/events/v1'
  _globals['_INSIGHTCOMPLETE']._serialized_start=237
  _globals['_INSIGHTCOMPLETE']._serialized_end=565
# @@protoc_insertion_point(module_scope)
